Learn R Programming

ViSe (version 0.1.3)

d_to_nnt: Convert d to Number Needed to Treat

Description

This function calculates the number needed to treat from continuous measures (Cohen's d) using Kraemer and Kupfer (2006) formula.

Usage

d_to_nnt(d = NULL)

Value

nnt values from d

Arguments

d

the effect size

References

Kraemer H.C., Kupfer D.J. (2006) Size of treatment effects and their importance to clinical research and practice. Biolological Psychiatry, 59, 990–996. https://doi.org/10.1016/j.biopsych.2005.09.014

Examples

Run this code

d_to_nnt(d = .25)

Run the code above in your browser using DataLab